Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1261)

Unified Diff: components/image_fetcher/ios/ios_image_data_fetcher_wrapper.h

Issue 2677993002: Use IOSImageDataFetcherWrapper for favicon (Closed)
Patch Set: Cleanup WebState Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/image_fetcher/ios/ios_image_data_fetcher_wrapper.h
diff --git a/components/image_fetcher/ios/ios_image_data_fetcher_wrapper.h b/components/image_fetcher/ios/ios_image_data_fetcher_wrapper.h
index 81b5f70dbdfccfb4c9b31f2289a0bb31ca6eae3c..3f49cc5b5c3f22e27c736ba2053420c8fdc1c8ef 100644
--- a/components/image_fetcher/ios/ios_image_data_fetcher_wrapper.h
+++ b/components/image_fetcher/ios/ios_image_data_fetcher_wrapper.h
@@ -23,8 +23,10 @@ class GURL;
namespace image_fetcher {
-// Callback that informs of the download of an image encoded in |data|.
-using IOSImageDataFetcherCallback = void (^)(NSData* data);
+// Callback that informs of the download of an image encoded in |data| with the
+// http |response_code| of the download.
+using IOSImageDataFetcherCallback = void (^)(NSData* data,
+ const int response_code);
sdefresne 2017/02/06 17:33:34 Remove "const" here. It is not really necessary (i
gambard 2017/02/07 10:03:33 Done.
class IOSImageDataFetcherWrapper {
public:

Powered by Google App Engine
This is Rietveld 408576698